@@ -1,15 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Channel Nick List, including context menu
-  begin:     Fre Jun 7 2002
-  copyright: (C) 2002 by Dario Abatianni
-  email:     eisfuchs@tigress.com
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
 */
 
 #ifndef NICKLISTVIEW_H
@@ -22,14 +14,16 @@
 #include <QTreeWidget>
 
 
-class QTimer;
 
 
+/**
+ *  Channel Nick List, including context menu
+ */
 class NickListView : public QTreeWidget
 {
     Q_OBJECT
 
-        public:
+    public:
         NickListView(QWidget* parent, Channel *chan);
         ~NickListView() override;
 
@@ -52,6 +46,9 @@ class NickListView : public QTreeWidget
             private:
                 NickListView *w;
                 bool enabled;
+
+                Q_DISABLE_COPY(NoSorting)
+
             public:
                 NoSorting(NickListView *w) : w(w), enabled(w->isSortingEnabled())
                 {
@@ -80,11 +77,13 @@ class NickListView : public QTreeWidget
         void dragEnterEvent(QDragEnterEvent *event) override;
         void dragMoveEvent(QDragMoveEvent *event) override;
 
-        Channel *channel;
-        QTimer *m_resortTimer;
-
     private:
+        Channel *m_channel;
+
         static int s_minimumRowHeight;
         static void updateMinimumRowHeight();
+
+        Q_DISABLE_COPY(NickListView)
 };
+
 #endif
